;; Generated package description from org-real.el  -*- no-byte-compile: t -*-
(define-package "org-real" "1.0.6" "Keep track of real things as org-mode links" '((emacs "26.1") (boxy "1.0") (org "9.3")) :commit "9ae5d4a2c576671e8f7ab20d202eefa65af51b25" :authors '(("Taylor Grinn" . "grinntaylor@gmail.com")) :maintainer '("Taylor Grinn" . "grinntaylor@gmail.com") :keywords '("tools") :url "https://gitlab.com/tygrdev/org-real")
